clear all; clc; close all;

%% Design of Windowed Sinc RF Pulses
tbw = 16;
samples = 512;

rf = wsinc(tbw, samples);

%% Plot RF Amplitude
tbw = 16;
samples = 512;

rf = (pi/2)*wsinc(tbw,samples);

pulseduration = 1; % in ms
rfs = rfscaleg(rf, pulseduration); % Scaled to Gauss

dt = pulseduration/samples;
t = (1:length(rfs))*dt;  % in msec

b1    = [rfs zeros(1,samples/2)];                 % in Gauss
g     = [ones(1,samples) -ones(1,samples/2)];     % in G/cm
t_all = (1:length(g))*dt;  % in msec

figure(1); 
subplot(311); plot(t_all,b1); grid on; 
xlabel('Time (msec)'); ylabel('B_1 (Gauss)');

subplot(312); plot(t_all,g); grid on; 
xlabel('Time (msec)'); ylabel('G_z (Gauss/cm)');

%% Simulate Slice Profile using Bloch Simulation
x = (-4:.1:4);          % in cm
f = 0;                  % in Hz
dt = pulseduration/samples/1e3;
t = (1:length(b1))*dt;  % in usec

% Bloch Simulation
[mx,my,mz] = bloch(b1(:),g(:),t(:),1,.2,f(:),x(:),0); 

% Transverse Magnetization
mxy = mx+1i*my;

figure(1); subplot(313); plot(x,abs(mxy)); 
grid on; xlabel('z position (cm)');

%% Simulate Slice Profile using Small Tip Approximation
gamma_2pi = 4.257;
gmax = 1;

samples_st = 4096;
f_st = linspace(-0.5/dt, 0.5/dt, samples_st)/1e3;
x_st = -f_st/(gamma_2pi*gmax);
rfs_zp = zeros(1,samples_st);
rfs_zp(1:samples) = rfs;

mxy_st = fftshift(fftn(fftshift(rfs_zp)))/30;

figure(2); subplot(313); plot(x_st,abs(mxy_st)); 
grid on; xlabel('z position (cm)');
axis([-4 4 0 1]);


